:mod:`eulfedora.api` - Fedora API access
========================================

.. module:: eulfedora.api

API wrapper
-----------

.. autoclass:: ApiFacade
    :members:


REST API
--------

.. autoclass:: REST_API
    :members:

API_A_LITE
----------

.. autoclass:: API_A_LITE
    :members:


Resource Index
--------------

.. autoclass:: ResourceIndex
    :members:
